<?php

if ( ! defined( 'ABSPATH' ) ) {
    exit ;
}
if ( ! class_exists( 'RS_Add_Points_For_User' ) ) {

    /**
     * RS_Add_Points_For_User Class.
     */
    class RS_Add_Points_For_User extends WP_Background_Process {

        /**
         * @var string
         */
        protected $action = 'rs_add_points_for_user_updater' ;

        /**
         * Task
         *
         * Override this method to perform any actions required on each
         * queue item. Return the modified item for further processing
         * in the next pass through. Or, return false to remove the
         * item from the queue.
         *
         * @param mixed $item Queue item to iterate over
         *
         * @return mixed
         */
        protected function task( $item ) {
            $this->add_points_for_user( $item ) ;
            return false ;
        }

        /**
         * Complete
         *
         * Override if applicable, but ensure that the below actions are
         * performed, or, call parent::complete().
         */
        protected function complete() {
            parent::complete() ;
            $offset            = get_option( 'rs_add_points_background_updater_offset' ) ;
            $UserSelectionType = get_option( 'rs_user_selection_type' ) ;
            $Includeuser       = get_option( 'rs_include_user_to_add_points' ) ;
            $Excludeuser       = get_option( 'rs_exclude_user_to_add_points' ) ;
            if ( $UserSelectionType == '1' ) {
                $args   = array( 'fields' => 'ID' ) ;
                $UserId = get_users( $args ) ;
            } else if ( $UserSelectionType == '2' ) {
                $UserId = is_array( $Includeuser ) ? $Includeuser : explode( ',' , $Includeuser ) ;
            } else if ( $UserSelectionType == '3' ) {
                $ExcludedId = is_array( $Excludeuser ) ? $Excludeuser : explode( ',' , $Excludeuser ) ;
                $args       = array( 'fields' => 'ID' ) ;
                $AllUsers   = get_users( $args ) ;
                foreach ( $AllUsers as $User ) {
                    if ( ! in_array( $User , $ExcludedId ) ) {
                        $UserId[] = $User ;
                    }
                }
            }
            $SlicedArray = array_slice( $UserId , $offset , 1000 ) ;
            if ( srp_check_is_array( $SlicedArray ) ) {
                RS_Main_Function_for_Background_Process::callback_to_add_points_for_user( $offset ) ;
                RS_Main_Function_for_Background_Process::$rs_progress_bar->fp_increase_progress( 75 ) ;
            } else {
                RS_Main_Function_for_Background_Process::$rs_progress_bar->fp_increase_progress( 100 ) ;
                FP_WooCommerce_Log::log( 'Points for User(s) added Successfully' ) ;
                delete_option( 'rs_add_points_background_updater_offset' ) ;
            }
        }

        public function add_points_for_user( $UserId ) {
            if ( $UserId != 'no_users' ) {
                if ( get_option( 'rs_state_to_add_points_for_user' ) == 'yes' ) {
                    $ExpiryDate     = get_option( 'rs_expireddate_for_added_points' ) ;
                    $ExpiryDate     = strtotime( $ExpiryDate ) ;
                    $subject        = get_option( 'rs_email_subject_to_send_mail_for_user' ) ;
                    $message        = get_option( 'rs_email_message_to_send_mail_for_user' ) ;
                    update_option( 'rs_email_subject_message' , $subject ) ;
                    update_option( 'rs_email_message' , $message ) ;
                    $user_info      = get_userdata( $UserId ) ;
                    $to             = is_object( $user_info ) ? $user_info->user_email : '' ;
                    $PointsToAdd    = get_option( 'rs_points_to_add_user' ) ;
                    $reasonindetail = get_option( 'rs_reason_to_add_points_for_user' ) ;
                    $new_obj        = new RewardPointsOrder( 0 , 'no' ) ;
                    $headers        = "MIME-Version: 1.0\r\n" ;
                    $headers        .= "Content-Type: text/html; charset=UTF-8\r\n" ;
                    $headers        .= "From: " . get_option( 'woocommerce_email_from_name' ) . " <" . get_option( 'woocommerce_email_from_address' ) . ">\r\n" ;
                    $headers        .= "Reply-To: " . get_option( 'woocommerce_email_from_name' ) . " <" . get_option( 'woocommerce_email_from_address' ) . ">\r\n" ;
                    $PointsData     = new RS_Points_data( $UserId ) ;
                    if ( get_option( 'rs_enable_disable_max_earning_points_for_user' ) == 'yes' ) {
                        $new_obj->check_point_restriction( $PointsToAdd , 0 , 'MAP' , $UserId , '' , '' , '' , '' , $reasonindetail ) ;
                    } else {
                        $valuestoinsert = array( 'expireddate' => $ExpiryDate , 'manualaddpoints' => 'yes' , 'pointstoinsert' => $PointsToAdd , 'event_slug' => 'MAP' , 'user_id' => $UserId , 'reasonindetail' => $reasonindetail , 'totalearnedpoints' => $PointsToAdd ) ;
                        $new_obj->total_points_management( $valuestoinsert ) ;
                    }
                    if ( (get_option( 'rs_send_mail_for_user_to_add_points' ) == true) && ($PointsToAdd != '') ) {
                        $Expiry            = ( get_option( 'rs_expireddate_for_added_points' ) != '' ) ? get_option( 'rs_expireddate_for_added_points' ) : 'All Time Usage' ;
                        $shortcode_message = str_replace( '[rs_earned_points]' , $PointsToAdd , str_replace( '[rs_expiry]' , $Expiry , $message ) ) ;
                        $replaced_message  = str_replace( '[balance_points]' , $PointsData->total_available_points() , $shortcode_message ) ;
                        $finalmsg          = str_replace( '[site_name]' , get_option( 'blogname' ) , $replaced_message ) ;
                        wp_mail( $to , $subject , $finalmsg , $headers ) ;
                    }
                }
            }
            return $UserId ;
        }

    }

}