<?php

if ( ! defined( 'ABSPATH' ) ) {
    exit ;
}
if ( ! class_exists( 'RS_Remove_Points_For_User' ) ) {

    /**
     * RS_Remove_Points_For_User Class.
     */
    class RS_Remove_Points_For_User extends WP_Background_Process {

        /**
         * @var string
         */
        protected $action = 'rs_remove_points_for_user_updater' ;

        /**
         * Task
         *
         * Override this method to perform any actions required on each
         * queue item. Return the modified item for further processing
         * in the next pass through. Or, return false to remove the
         * item from the queue.
         *
         * @param mixed $item Queue item to iterate over
         *
         * @return mixed
         */
        protected function task( $item ) {
            $this->remove_points_for_user( $item ) ;
            return false ;
        }

        /**
         * Complete
         *
         * Override if applicable, but ensure that the below actions are
         * performed, or, call parent::complete().
         */
        protected function complete() {
            parent::complete() ;
            $offset            = get_option( 'rs_remove_points_background_updater_offset' ) ;
            $UserSelectionType = get_option( 'rs_user_selection_type' ) ;
            $Includeuser       = get_option( 'rs_include_user_to_remove_points' ) ;
            $Excludeuser       = get_option( 'rs_exclude_user_to_remove_points' ) ;
            if ( $UserSelectionType == '1' ) {
                $args   = array( 'fields' => 'ID' ) ;
                $UserId = get_users( $args ) ;
            } else if ( $UserSelectionType == '2' ) {
                $UserId = is_array( $Includeuser ) ? $Includeuser : explode( ',' , $Includeuser ) ;
            } else if ( $UserSelectionType == '3' ) {
                $ExcludedId = is_array( $Excludeuser ) ? $Excludeuser : explode( ',' , $Excludeuser ) ;
                $args       = array( 'fields' => 'ID' ) ;
                $AllUsers   = get_users( $args ) ;
                foreach ( $AllUsers as $User ) {
                    if ( ! in_array( $User , $ExcludedId ) ) {
                        $UserId[] = $User ;
                    }
                }
            }
            $SlicedArray = array_slice( $UserId , $offset , 1000 ) ;
            if ( is_array( $SlicedArray ) && ! empty( $SlicedArray ) ) {
                RS_Main_Function_for_Background_Process::callback_to_remove_points_for_user( $offset ) ;
                RS_Main_Function_for_Background_Process::$rs_progress_bar->fp_increase_progress( 75 ) ;
            } else {
                RS_Main_Function_for_Background_Process::$rs_progress_bar->fp_increase_progress( 100 ) ;
                FP_WooCommerce_Log::log( 'Points for User(s) removed Successfully' ) ;
                delete_option( 'rs_remove_points_background_updater_offset' ) ;
            }
        }

        public function remove_points_for_user( $UserId ) {
            if ( $UserId != 'no_users' ) {
                if ( get_option( 'rs_state_to_remove_points_for_user' ) == 'yes' ) {
                    $subject        = get_option( 'rs_email_subject_to_remove_points' ) ;
                    $message        = get_option( 'rs_email_message_to_remove_points' ) ;
                    update_option( 'rs_email_subject_for_remove' , $subject ) ;
                    update_option( 'rs_email_message_for_remove' , $message ) ;
                    global $wpdb ;
                    $table_name     = $wpdb->prefix . 'rspointexpiry' ;
                    $PointsData     = new RS_Points_data( $UserId ) ;
                    $totalpoints    = $PointsData->total_available_points() ;
                    $reasonindetail = get_option( 'rs_reason_to_remove_points_for_user' ) ;
                    $user_info      = get_userdata( $UserId ) ;
                    $to             = is_object( $user_info ) ? $user_info->user_email : '' ;
                    $headers        = "MIME-Version: 1.0\r\n" ;
                    $headers        .= "Content-Type: text/html; charset=UTF-8\r\n" ;
                    $headers        .= "From: " . get_option( 'woocommerce_email_from_name' ) . " <" . get_option( 'woocommerce_email_from_address' ) . ">\r\n" ;
                    $headers        .= "Reply-To: " . get_option( 'woocommerce_email_from_name' ) . " <" . get_option( 'woocommerce_email_from_address' ) . ">\r\n" ;
                    $removedpoints  = get_option( 'rs_points_to_remove_user' ) ;
                    if ( $removedpoints <= $totalpoints ) {
                        $pointsredeemed = RSPointExpiry::perform_calculation_with_expiry( $removedpoints , $UserId ) ;
                        $table_args     = array(
                            'user_id'     => $UserId ,
                            'usedpoints'  => $removedpoints ,
                            'checkpoints' => 'MRP' ,
                            'date'        => '999999999999' ,
                            'reason'      => $reasonindetail ,
                                ) ;
                        RSPointExpiry::record_the_points( $table_args ) ;
                        if ( (get_option( 'rs_send_mail_for_user_to_remove_points' ) == true ) ) {
                            $finalmsg = str_replace( array( '[rs_deleted_points]' , '[balance_points]' , '[site_name]' ) , array( $removedpoints , $totalpoints , get_option( 'blogname' ) ) , $message ) ;
                            wp_mail( $to , $subject , $finalmsg , $headers ) ;
                        }
                    }
                }
            }
            return $UserId ;
        }

    }

}