<?php

/*
 * Reward Points Data
 */
if ( ! defined( 'ABSPATH' ) )
    exit ; // Exit if accessed directly.

if ( ! class_exists( 'RS_Points_Data' ) ) {

    /**
     * RS_Points_Data Class.
     */
    class RS_Points_Data {

        /**
         * ID
         */
        protected $id = '' ;

        /**
         * Class initialization.
         */
        public function __construct( $_id = '' ) {
            $this->id = $_id ;
        }

        /**
         * Insert Points for User
         */
        public function insert_points() {
            
        }

        /* Total Earned Points in Site for User */

        public function total_earned_points() {
            if ( ! $this->id )
                return 0 ;

            global $wpdb ;
            $PointsTable = $wpdb->prefix . "rspointexpiry" ;
            $TotalPoints = $wpdb->get_results( $wpdb->prepare( "SELECT SUM(earnedpoints) as availablepoints FROM $PointsTable WHERE earnedpoints NOT IN(0) and userid = %d" , $this->id ) , ARRAY_A ) ;

            if ( ! srp_check_is_array( $TotalPoints ) )
                return 0 ;

            $DeletedPoints               = get_user_meta( $this->id , 'rs_earned_points_before_delete' , true ) ;
            $PointsInOldMeta             = get_user_meta( $this->id , 'rs_user_total_earned_points' , true ) ;
            $ExpiredPoints               = get_user_meta( $this->id , 'rs_expired_points_before_delete' , true ) ;
            $PointsInOldVersion          = get_user_meta( $this->id , '_my_reward_points' , true ) ;
            $RemainingPointsInOldVersion = ( $PointsInOldMeta > $PointsInOldVersion ) ? $PointsInOldMeta - $PointsInOldVersion : 0 ;

            foreach ( $TotalPoints as $Points ) {
                $Point = $Points[ 'availablepoints' ] + ( float ) $DeletedPoints + ( float ) $RemainingPointsInOldVersion + ( float ) $ExpiredPoints ;
            }

            return round_off_type( $Point ) ;
        }

        /* Available Points for User */

        public function total_available_points() {
            if ( ! $this->id )
                return 0 ;

            global $wpdb ;
            $PointsTable     = $wpdb->prefix . 'rspointexpiry' ;
            $AvailablePoints = $wpdb->get_results( $wpdb->prepare( "SELECT SUM((earnedpoints-usedpoints)) as availablepoints FROM $PointsTable WHERE earnedpoints-usedpoints NOT IN(0) and expiredpoints IN(0) and userid = %d" , $this->id ) , ARRAY_A ) ;
            if ( ! srp_check_is_array( $AvailablePoints ) )
                return 0 ;

            foreach ( $AvailablePoints as $Points ) {
                $Point = ! empty( $Points[ 'availablepoints' ] ) ? $Points[ 'availablepoints' ] : 0 ;
            }

            return round_off_type( $Point ) ;
        }

        /* Available Points for User */

        public function total_available_points_as_currency() {
            if ( ! $this->id )
                return 0 ;

            global $wpdb ;
            $PointsTable     = $wpdb->prefix . 'rspointexpiry' ;
            $AvailablePoints = $wpdb->get_results( $wpdb->prepare( "SELECT SUM((earnedpoints-usedpoints)) as availablepoints FROM $PointsTable WHERE earnedpoints-usedpoints NOT IN(0) and expiredpoints IN(0) and userid = %d" , $this->id ) , ARRAY_A ) ;
            if ( ! srp_check_is_array( $AvailablePoints ) )
                return 0 ;

            foreach ( $AvailablePoints as $Points ) {
                $Point = ! empty( $Points[ 'availablepoints' ] ) ? $Points[ 'availablepoints' ] : 0 ;
            }

            $ConvertedRate = redeem_point_conversion( $Point , $this->id , 'price' ) ;
            return get_woocommerce_currency_symbol() . round_off_type_for_currency( $ConvertedRate ) ;
        }

        /* Total Redeemed Points in Site for User */

        public function total_redeemed_points() {
            if ( ! $this->id )
                return 0 ;

            global $wpdb ;
            $PointsTable    = $wpdb->prefix . "rspointexpiry" ;
            $RedeemedPoints = $wpdb->get_results( $wpdb->prepare( "SELECT SUM(usedpoints) as redeemedpoints FROM $PointsTable WHERE usedpoints NOT IN(0) and userid=%d" , $this->id ) , ARRAY_A ) ;
            if ( ! srp_check_is_array( $RedeemedPoints ) )
                return 0 ;

            foreach ( $RedeemedPoints as $Points ) {
                $PointsinOlderVersion = self::redeemed_points_in_older_version() ;
                $DeletedPoints        = ( float ) get_user_meta( $this->id , 'rs_redeem_points_before_delete' , true ) ;
                $Point                = $Points[ 'redeemedpoints' ] + $PointsinOlderVersion + $DeletedPoints ;
            }

            return round_off_type( $Point ) ;
        }

        public function redeemed_points_in_older_version() {
            $Point                = 0 ;
            $PointsInOlderVersion = get_user_meta( $this->id , '_my_points_log' , true ) ;
            if ( ! srp_check_is_array( $PointsInOlderVersion ) )
                return $Point ;

            foreach ( $PointsInOlderVersion as $Points ) {
                if ( ! isset( $Points[ 'points_redeemed' ] ) )
                    continue ;

                if ( ! empty( $Points[ 'points_redeemed' ] ) )
                    $Point += $Points[ 'points_redeemed' ] ;
            }
            return round_off_type( $Point ) ;
        }

        /* Total Expired Points in Site for User */

        public function total_expired_points() {
            if ( ! $this->id )
                return 0 ;

            global $wpdb ;
            $PointsTable   = $wpdb->prefix . "rspointexpiry" ;
            $ExpiredPoints = $wpdb->get_results( $wpdb->prepare( "SELECT SUM(expiredpoints) as expiredpoints FROM $PointsTable WHERE expiredpoints NOT IN(0) and userid=%d" , $this->id ) , ARRAY_A ) ;
            if ( ! srp_check_is_array( $ExpiredPoints ) )
                return 0 ;

            foreach ( $ExpiredPoints as $Points ) {
                $DeletedPoints = ( float ) get_user_meta( $this->id , 'rs_expired_points_before_delete' , true ) ;
                $Point         = $Points[ 'expiredpoints' ] + $DeletedPoints ;
            }

            return round_off_type( $Point ) ;
        }

        /* Points Log for Specific User */

        public function points_log_for_specific_user( $where = '' ) {
            if ( ! $this->id )
                return array() ;

            global $wpdb ;
            $PointsTable = $wpdb->prefix . 'rspointexpiry' ;
            $PointsLog   = $wpdb->get_results( $wpdb->prepare( "SELECT * FROM $PointsTable WHERE userid = %d $where" , $this->id ) , ARRAY_A ) ;
            if ( ! srp_check_is_array( $PointsLog ) )
                return array() ;

            return $PointsLog ;
        }

        /* Update User Meta */

        public function update_meta( $meta_key , $value ) {
            if ( ! $this->id )
                return false ;

            update_user_meta( $this->id , $meta_key , $value ) ;
        }

    }

}