<?php

if ( ! defined( 'ABSPATH' ) ) {
    exit ; // Exit if accessed directly.
}

if ( ! class_exists( 'RSFunctionForAdvanced' ) ) {

    class RSFunctionForAdvanced {

        public static function init() {
            if ( get_option( 'rs_load_script_styles' ) == 'wp_head' ) {
                add_action( 'wp_head' , array( __CLASS__ , 'load_script_in_header_or_footer' ) ) ;
            } else {
                add_action( 'wp_footer' , array( __CLASS__ , 'load_script_in_header_or_footer' ) ) ;
            }
            if ( get_option( 'rs_reward_content_menu_page' ) == 'yes' ) {
                $TitleURL = get_option( 'rs_my_reward_url_title' ) != '' ? get_option( 'rs_my_reward_url_title' ) : 'sumo-rewardpoints' ;
                add_filter( 'woocommerce_account_menu_items' , array( __CLASS__ , 'add_reward_menu_in_myaccount' ) ) ;
                add_action( 'woocommerce_account_' . $TitleURL . '_endpoint' , array( __CLASS__ , 'reward_contents_in_menu_page' ) ) ;
            }
        }

        public static function load_script_in_header_or_footer() {
            if ( get_option( 'rs_reward_point_dequeue_select2' ) == 'yes' )
                wp_dequeue_script( 'edgt_select2' ) ;

            if ( get_option( 'rs_reward_point_dequeue_recaptcha' ) == 'yes' )
                wp_dequeue_script( 'wp_google_recaptcha' ) ;
        }

        public static function add_reward_menu_in_myaccount( $items ) {
            $TitleURL   = get_option( 'rs_my_reward_url_title' ) != '' ? get_option( 'rs_my_reward_url_title' ) : 'sumo-rewardpoints' ;
            $RewardMenu = array( $TitleURL => get_option( 'rs_my_reward_content_title' ) ) ;
            $items      = array_slice( $items , 0 , 2 ) + $RewardMenu + array_slice( $items , 2 , count( $items ) - 1 ) ;
            return $items ;
        }

        public static function reward_contents_in_menu_page() {
            if ( get_option( 'rs_my_reward_table_menu_page' ) == '1' )
                RSFunctionForMessage::reward_log() ;

            if ( get_option( 'rs_cashback_activated' ) == 'yes' && get_option( 'rs_my_cashback_table_menu_page' ) == '1' )
                RSCashBackFrontend::cash_back_log() ;

            if ( get_option( 'rs_nominee_activated' ) == 'yes' && get_option( 'rs_show_hide_nominee_field_menu_page' ) == '1' )
                RSFunctionForNominee::display_nominee_field_in_my_account() ;

            if ( get_option( 'rs_gift_voucher_activated' ) == 'yes' && get_option( 'rs_show_hide_redeem_voucher_menu_page' ) == '1' )
                RSGiftVoucherFrontend::giftvoucherfield() ;

            if ( get_option( 'rs_referral_activated' ) == 'yes' ) {
                if ( get_option( 'rs_show_hide_referal_table_menu_page' ) == '1' ) {
                    if ( check_if_referral_is_restricted_based_on_history() )
                        RSFunctionForReferralSystem::referral_list_table_in_menu() ;
                }
                if ( get_option( 'rs_show_hide_generate_referral_menu_page' ) == '1' ) {
                    if ( get_option( 'rs_show_hide_generate_referral_link_type' ) == '2' ) {
                        if ( check_if_referral_is_restricted_based_on_history() )
                            RSFunctionForReferralSystem::static_referral_link() ;
                    } else {
                        if ( check_if_referral_is_restricted_based_on_history() )
                            RSFunctionForReferralSystem::list_of_generated_link_and_field() ;
                    }
                }
            }
            if ( get_option( 'rs_email_activated' ) == 'yes' && get_option( 'rs_show_hide_your_subscribe_link_menu_page' ) == 1 )
                RSFunctionForEmailTemplate::field_for_subcribe() ;
        }

    }

    RSFunctionForAdvanced::init() ;
}